#ifndef _MATCH_OPS_H_INCLUDED_
#define _MATCH_OPS_H_INCLUDED_

/*++
/* NAME
/*	match_ops 3h
/* SUMMARY
/*	simple string or host pattern matching
/* SYNOPSIS
/*	#include <match_ops.h>
/* DESCRIPTION
/* .nf

 /*
  * Utility library.
  */
#include <vstring.h>

 /* External interface. */

#define MATCH_FLAG_NONE		0
#define MATCH_FLAG_PARENT	(1<<0)
#define MATCH_FLAG_STRICT_ADDR	(1<<1)
#define MATCH_FLAG_NOLOOKUP	(1<<2)
#define MATCH_FLAG_NONNULL_HOST	(1<<3)
#define MATCH_FLAG_ALL		(MATCH_FLAG_PARENT | MATCH_FLAG_NOLOOKUP | MATCH_FLAG_NONNULL_HOST)

#define GAI_STRERROR(error) \
	((error == EAI_SYSTEM) ? strerror(errno) : gai_strerror(error))

 /* Data structures. */

typedef struct ADDR_PATTERN {
    struct sockaddr *addr;		/* pointer to sockaddr(_storage) address */
    size_t masklen;			/* prefix length */
    char  *pattern;			/* modified pattern */
    char  *opattern;			/* original string pattern */
} ADDR_PATTERN;

extern int match_string(int, const char *, const char *);
extern int match_hostname(int, const char *, const char *);
extern int match_hostaddr(int, const char *, const char *);
extern int std_addr_pattern(int, const char *, ADDR_PATTERN **, VSTRING *);
extern int match_sockaddr(const struct sockaddr *, const struct sockaddr *, int);

extern ADDR_PATTERN * addr_pattern_init(void);
extern void addr_pattern_free(ADDR_PATTERN *);

/* LICENSE
/* .ad
/* .fi
/*	The Secure Mailer license must be distributed with this software.
/* AUTHOR(S)
/*	Wietse Venema
/*	IBM T.J. Watson Research
/*	P.O. Box 704
/*	Yorktown Heights, NY 10598, USA
/*
/*	Dean C. Strik
/*	Department ICT Services
/*	Eindhoven University of Technology
/*	P.O. Box 513
/*	5600 MB  Eindhoven, Netherlands
/*	E-mail: <dean@ipnet6.org>
/*--*/

#endif
